Faker class

Constructors

Faker({int? seed, FakerDataProvider? provider})
factory
Faker.withGenerator(RandomGenerator random, {FakerDataProvider? provider})

Properties

address → Address
final
animal → Animal
final
color → Color
final
company → Company
final
conference → Conference
final
currency → Currency
final
date → Date
final
food → Food
final
geo → Geo
final
guid → Guid
final
hashCode → int
The hash code for this object.
no setterinherited
image → Image
final
internet → Internet
final
job → Job
final
jwt → Jwt
final
lorem → Lorem
final
person → Person
final
phoneNumber → PhoneNumber
final
randomGenerator → RandomGenerator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sport → Sport
final
vehicle → Vehicle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited